[![build](https://img.shields.io/github/actions/workflow/status/rokugu/rokugu/publish.yml)](https://github.com/rokugu/rokugu/actions)
[![last commit](https://img.shields.io/github/last-commit/rokugu/rokugu)](https://github.com/rokugu/rokugu/commits/main)
[![license](https://img.shields.io/github/license/rokugu/rokugu)](https://github.com/rokugu/rokugu/blob/main/LICENSE)
[![pypi](https://img.shields.io/pypi/v/rokugu)](https://pypi.org/project/rokugu)

![screenshot](https://raw.githubusercontent.com/rokugu/rokugu/main/screenshot.png)

---

An opinionated PySide6 library that delivers ready-to-use components and
utilities, empowering developers to build high-quality UIs with a focused,
efficient approach.
